##  Code Configurations and Execution Log
You can view all custom code configurations used in automations with scripts in the Managed Code section of the administration area. Here, you can monitor execution logs to track history and resolve issues. For more information, see [Managed Code](https://help.sap.com/docs/leanix/ea/managed-code?locale=en-US&state=PRODUCTION&version=CLOUD "View and manage all custom code configurations used in automations, calculations, and webhooks across your workspace. Monitor execution logs to track history, troubleshoot issues, and ensure your code runs as expected.").
